@@ -16,7 +16,7 @@
 import yaml
 
 
-from eva.configuration.dictionary import EVA_DATASET_DIR, \
+from eva.configuration.dictionary import EVA_DEFAULT_DIR, \
     EVA_CONFIG_FILE
 from eva.configuration.config_utils import read_value_config, \
     update_value_config
@@ -30,7 +30,7 @@ class ConfigurationManager(object):
         if cls._instance is None:
             cls._instance = super(ConfigurationManager, cls).__new__(cls)
 
-            ymlpath = EVA_DATASET_DIR + EVA_CONFIG_FILE
+            ymlpath = EVA_DEFAULT_DIR + EVA_CONFIG_FILE
             with open(ymlpath, 'r') as ymlfile:
                 cls._cfg = yaml.load(ymlfile, Loader=yaml.FullLoader)
 
